# Talos Resource Provider

The Talos Resource Provider lets you manage [Talos Linux](https://talos.dev) machines & clusters.

## Installing

This package is available for several languages/platforms:

### Go

To use from Go, use `go get` to grab the latest version of the library:

```bash
go get github.com/pulumiverse/pulumi-talos/sdk/go/...
```

## Reference

For detailed reference documentation, please visit [the Pulumi registry](https://www.pulumi.com/registry/packages/talos/api-docs/).
